=======================================================================
 Faust - Python Stream Processing
=======================================================================

.. sourcecode:: python

    # Python Streams ٩(◕‿◕)۶
    # Forever scalable event processing & in-memory durable K/V store;
    # w/ asyncio & static typing.
    import faust

.. include:: includes/intro.txt

-----------------------------------

Contents
========

.. toctree::
    :maxdepth: 1

    copyright

.. toctree::
    :maxdepth: 2

    introduction

.. toctree::
    :maxdepth: 2

    playbooks/index

.. toctree::
    :maxdepth: 2

    userguide/index

.. toctree::
    :maxdepth: 1

    faq
    reference/index
    changelog
    contributing
    developerguide/index
    history/index
    authors
    glossary

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

